# pygismeteo-base

[![pre-commit.ci status](https://results.pre-commit.ci/badge/github/monosans/pygismeteo-base/main.svg)](https://results.pre-commit.ci/latest/github/monosans/pygismeteo-base/main)
[![PyPI Downloads](https://img.shields.io/pypi/dm/pygismeteo-base?logo=pypi)](https://pypi.org/project/pygismeteo-base/)

База для [pygismeteo](https://github.com/monosans/pygismeteo) и [aiopygismeteo](https://github.com/monosans/aiopygismeteo).

## License / Лицензия

[MIT](https://github.com/monosans/pygismeteo-base/blob/main/LICENSE)
